@@ -5,16 +5,15 @@ package Test::Deep::Any;
 
 use Test::Deep::Cmp;
 
-use overload
-	'&' => \&add,
-	fallback => 1,
-;
-
 sub init
 {
 	my $self = shift;
 
-	my @list = map {Test::Deep::wrap($_)} @_;
+	my @list = map {
+	  eval { $_->isa('Test::Deep::Any') }
+	  ? @{ $_->{val} }
+	  : Test::Deep::wrap($_)
+	} @_;
 
 	$self->{val} = \@list;
 }
@@ -32,34 +31,32 @@ sub descend
 	return 0;
 }
 
+sub renderExp
+{
+	my $self = shift;
+
+	my $expect = $self->{val};
+	my $things = join(", ", map {$_->renderExp} @$expect);
+
+	return "Any of ( $things )";
+}
+
 sub diagnostics
 {
 	my $self = shift;
 	my ($where, $last) = @_;
 
-	my $expect = $self->{val};
-
 	my $got = $self->renderGot($last->{got});
-	my $things = join(", ", map {$_->renderExp} @$expect);
+  my $exp = $self->renderExp;
 
 	my $diag = <<EOM;
 Comparing $where with Any
 got      : $got
-expected : Any of ( $things )
+expected : $exp
 EOM
 
 	$diag =~ s/\n+$/\n/;
 	return $diag;
 }
 
-sub add
-{
-	my $self = shift;
-	my $expect = shift;
-
-	push(@{$self->{val}}, Test::Deep::wrap($expect));
-
-	return $self;
-}
-
-1;
+4;
